---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. 
2. 
3. 
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment**
 - Python Version: [e.g. 2.7.15]
 - OS: [e.g. Linux]
 - Demisto Version: [e.g. 4.1.0 b12345]
 - Content Version: [e.g. 19.5.0]

**Additional context**
Add any other context about the problem here.
